# README

## Package Contents

This package consists of the following files:

1. **check_ioa.py**: This script processes and analyzes the input GZIP files to generate output statistics related to register rejects, invite rejects, unexpected user-agents, and unexpected URIs.

2. **config.py**: This configuration file contains the parameters used by the `check_ioa.py` script. The expected parameters and their default values are as follows:
    - `uri_list`: A array of expected URI prefixes for validation. Default value: `[640, 650]`
    - `ua_list`: A array of expected user-agent strings. Default value: `["avaya 1x."]`
    - `business_countries_list`: A array of country codes to filter business-related calls. Default value: `["+1", "+44"]`

## Pre-requisites

Before running the program, ensure the following:
- Python is installed on your system.
- A directory containing the GZIP files is available on your local machine.

## How to Run the Program

To execute the program, use the following command line:
```bash
python check_ioa.py <directory_path>
```
## How to Read the Output

1. Number of Register Rejects:
    - The total number of registration rejects found in the input files, along with the top 5 extensions targeted.
```
Number of register rejects: 7982
Top 5 extensions targeted
-------------------------------------------
|     Extension      |      Rejects       |
-------------------------------------------
|       484940       |                 964|
|        5001        |                 371|
|       484999       |                 200|
|       484941       |                 198|
|        5009        |                 196|
-------------------------------------------
```
##
2. Number of Invite Rejects:
    - The total number of invite rejects and the top 5 callers rejected.
```
Number of invite rejects: 113
Top 5 callers rejected
------------------------------------------------------
|       Caller       |      Rejects       |   DIR    |
------------------------------------------------------
|       484900       |                  55|    IN    |
|       484901       |                  20|    IN    |
|        5002        |                  20|    IN    |
|        5020        |                  15|    IN    |
|        5001        |                   3|    IN    |
------------------------------------------------------
```
##
3. Number of Unexpected User-Agents:
    - The total number of registration attempts from unexpected user-agents, along with the expected user-agents prefixes and top unexpected user-agents.
```
Number of unexpected user-agents outside your ecosystem of devices: 8912
Expected User-agents starting with: avaya 1x.

Top unexpected user-agents registration attempts
----------------------------------------------------------------
|              Unexpected UA               | Register attempts |
----------------------------------------------------------------
|          Avaya Communicator/3.0          |               8300|
| Avaya Communicator/3.0 (3.8.0.136.14; Av |                410|
| Avaya Communicator for Mac/3.8.0.126.6 ( |                200|
|             PhonerLite 2.76              |                  2|
----------------------------------------------------------------
```
##
4. Number of Unexpected URI:
    - The total number of registration attempts from unexpected URIs, along with the expected URI prefixes and top unexpected URI attempts.
```
Number of unexpected URI outside your range of extension: 22178
Expected URI starting with: 640, 650

Top 5 unexpected URI registration attempts
-------------------------------------------
|   Unexpected URI   |      Register      |
-------------------------------------------
|       484940       |                2440|
|        5001        |                 893|
|        5002        |                 575|
|        5009        |                 500|
|       484941       |                 500|
-------------------------------------------
```